pub struct Document { /* private fields */ }Implementations
Sourceimpl Document
impl Document
pub fn version(&self) -> u32
pub fn creator(&self) -> &str
pub fn creation_date(&self) -> &[u32; 7]
pub fn global_settings(&self) -> GlobalSettings<'_>
pub fn objects(&self) -> Objects<'_> ⓘ
pub fn object_by_index(&self, index: u64) -> Option<Object<'_>>
pub fn from_parser<R>(
parser: Parser<R>,
settings: ImportSettings,
) -> Result<Self, DocumentParseError>where
R: BufRead,
Sourcepub fn from_binary_reader<R>(
reader: R,
settings: ImportSettings,
) -> Result<Self, DocumentParseError>
pub fn from_binary_reader<R>( reader: R, settings: ImportSettings, ) -> Result<Self, DocumentParseError>
Loads a binary FBX document through fbxcel’s tree API.
This is the chosen primary binary ingress for now:
- parse bytes into
AnyTree - adapt tree nodes into the existing
Documentfields - drop the
AnyTreeafter materialization so we do not persist both a full tree and a long-lived binary DOM side-by-side.