pub struct Object<'a> { /* private fields */ }Expand description
One FBX object id: metadata from LazyObject, template from definitions, subtree from arena.
Implementations
Sourceimpl<'a> Object<'a>
impl<'a> Object<'a>
pub fn name(&self) -> &str
pub fn type_name(&self) -> &str
pub fn class_name(&self) -> &str
pub fn object_index(&self) -> u64
pub fn element(&self) -> Option<&'a Element>
Sourcepub fn connected_object_ids(&self) -> &[u64]
pub fn connected_object_ids(&self) -> &[u64]
Indices of objects connected from this one via OO rows (C: "OO", self, dest).
Sourcepub fn object_property_targets(&self) -> &[ObjectPropertyConnection]
pub fn object_property_targets(&self) -> &[ObjectPropertyConnection]
OP connections from this object: each entry is a destination object id and the
destination-side property name (C: "OP", self, dest, property).
Sourcepub fn pp_source_property_names(&self) -> &[String]
pub fn pp_source_property_names(&self) -> &[String]
Property names on this object that appear as the source side of PP connections.
Sourcepub fn pp_targets(
&self,
key: (u64, &str),
) -> Option<&[ObjectPropertyConnection]>
pub fn pp_targets( &self, key: (u64, &str), ) -> Option<&[ObjectPropertyConnection]>
PP targets for a source (object_id, property_name) key (C: "PP", …).
The document’s PP map keys reuse ObjectPropertyConnection: for PP rows,
ObjectPropertyConnection::dest holds the source object id and property the source
property name.
Sourceimpl<'a> Object<'a>
impl<'a> Object<'a>
pub fn new( document: &'a Document, template: &'a Template, object: &'a LazyObject, index: u64, ) -> Self
pub fn template(&self) -> &'a Template
pub fn properties(&self) -> HashMap<String, Property>
pub fn attributes(&self) -> HashMap<String, ElementAttribute>