pub struct ObjectPropertyConnection {
pub dest: u64,
pub property: String,
}Expand description
Endpoint for OP / PP rows: destination object id and property name on that object.
For PP map keys, Assimp/FBX use the source side: ObjectPropertyConnection::dest is
the source object id and property the source property name; values are the actual
destination links. See crate::Object::pp_targets.
Fields
dest: u64property: StringTrait Implementations
Sourceimpl Clone for ObjectPropertyConnection
impl Clone for ObjectPropertyConnection
Sourcefn clone(&self) -> ObjectPropertyConnection
fn clone(&self) -> ObjectPropertyConnection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjectPropertyConnection
impl Debug for ObjectPropertyConnection
Sourceimpl Hash for ObjectPropertyConnection
impl Hash for ObjectPropertyConnection
Sourceimpl PartialEq for ObjectPropertyConnection
impl PartialEq for ObjectPropertyConnection
impl Eq for ObjectPropertyConnection
impl StructuralPartialEq for ObjectPropertyConnection